', {
+ description: d.description,
+ rate: ((d.charge_type == "Actual") ? '' : ("(" + d.rate + "%)")),
+ tax_amount: format_currency(flt(d.tax_amount)/flt(me.frm.doc.conversion_rate),
+ me.frm.doc.currency)
+ })).appendTo(".tax-table tbody");
+ }
});
},
set_totals: function() {
@@ -427,7 +450,7 @@ erpnext.POS = Class.extend({
$(this.wrapper).find('input, button').each(function () {
$(this).prop('disabled', true);
});
- $(this.wrapper).find(".delete-items").hide();
+ $(this.wrapper).find(".remove-items").hide();
$(this.wrapper).find(".make-payment").hide();
}
else {
@@ -437,14 +460,14 @@ erpnext.POS = Class.extend({
$(this.wrapper).find(".make-payment").show();
}
},
- make_payment_button: function() {
+ hide_payment_button: function() {
var me = this;
// Show Make Payment button only in Sales Invoice
if (this.frm.doctype != "Sales Invoice")
$(this.wrapper).find(".make-payment").hide();
},
refresh_delete_btn: function() {
- $(this.wrapper).find(".delete-items").toggle($(".item-cart .warning").length ? true : false);
+ $(this.wrapper).find(".remove-items").toggle($(".item-cart .warning").length ? true : false);
},
add_item_thru_barcode: function() {
var me = this;
@@ -466,7 +489,7 @@ erpnext.POS = Class.extend({
}
});
},
- remove_selected_item: function() {
+ remove_selected_items: function() {
var me = this;
var selected_items = [];
var no_of_items = $(this.wrapper).find("#cart tbody tr").length;
@@ -487,6 +510,7 @@ erpnext.POS = Class.extend({
}
}
});
+
this.refresh_grid();
},
refresh_grid: function() {
@@ -494,6 +518,22 @@ erpnext.POS = Class.extend({
this.frm.script_manager.trigger("calculate_taxes_and_totals");
this.refresh();
},
+ selected_item_qty_operation: function(item_code, operation) {
+ var me = this;
+ var child = wn.model.get_children(this.frm.doctype + " Item", this.frm.doc.name,
+ this.frm.cscript.fname, this.frm.doctype);
+
+ $.each(child, function(i, d) {
+ if (d.item_code == item_code) {
+ if (operation == "increase-qty")
+ d.qty += 1;
+ else if (operation == "decrease-qty")
+ d.qty != 1 ? d.qty -= 1 : d.qty = 1;
+
+ me.refresh();
+ }
+ });
+ },
make_payment: function() {
var me = this;
var no_of_items = $(this.wrapper).find("#cart tbody tr").length;
diff --git a/erpnext/accounts/doctype/sales_invoice/sales_invoice.js b/erpnext/accounts/doctype/sales_invoice/sales_invoice.js
index 9c6a9b223d..8e6ecc410f 100644
--- a/erpnext/accounts/doctype/sales_invoice/sales_invoice.js
+++ b/erpnext/accounts/doctype/sales_invoice/sales_invoice.js
@@ -54,7 +54,8 @@ erpnext.accounts.SalesInvoiceController = erpnext.selling.SellingController.exte
"voucher_no": doc.name,
"from_date": doc.posting_date,
"to_date": doc.posting_date,
- "company": doc.company
+ "company": doc.company,
+ group_by_voucher: 0
};
wn.set_route("query-report", "General Ledger");
}, "icon-table");
diff --git a/erpnext/accounts/doctype/sales_invoice/sales_invoice.py b/erpnext/accounts/doctype/sales_invoice/sales_invoice.py
index f77abfe72a..decfb425bd 100644
--- a/erpnext/accounts/doctype/sales_invoice/sales_invoice.py
+++ b/erpnext/accounts/doctype/sales_invoice/sales_invoice.py
@@ -88,6 +88,7 @@ class DocType(SellingController):
self.update_status_updater_args()
self.update_prevdoc_status()
+ self.update_billing_status_for_zero_amount_refdoc("Sales Order")
# this sequence because outstanding may get -ve
self.make_gl_entries()
@@ -114,6 +115,7 @@ class DocType(SellingController):
self.update_status_updater_args()
self.update_prevdoc_status()
+ self.update_billing_status_for_zero_amount_refdoc("Sales Order")
self.make_cancel_gl_entries()
diff --git a/erpnext/accounts/doctype/sales_invoice/sales_invoice.txt b/erpnext/accounts/doctype/sales_invoice/sales_invoice.txt
index 7de68a06ed..1a5bdf1efc 100644
--- a/erpnext/accounts/doctype/sales_invoice/sales_invoice.txt
+++ b/erpnext/accounts/doctype/sales_invoice/sales_invoice.txt
@@ -2,7 +2,7 @@
{
"creation": "2013-05-24 19:29:05",
"docstatus": 0,
- "modified": "2013-12-20 19:24:29",
+ "modified": "2014-01-16 15:36:16",
"modified_by": "Administrator",
"owner": "Administrator"
},
@@ -1094,7 +1094,7 @@
"fieldtype": "Select",
"label": "Recurring Type",
"no_copy": 1,
- "options": "Monthly\nQuarterly\nHalf-yearly\nYearly",
+ "options": "\nMonthly\nQuarterly\nHalf-yearly\nYearly",
"print_hide": 1,
"read_only": 0
},
diff --git a/erpnext/accounts/doctype/sales_invoice/test_sales_invoice.py b/erpnext/accounts/doctype/sales_invoice/test_sales_invoice.py
index c68b97a3b2..34ff97ff1c 100644
--- a/erpnext/accounts/doctype/sales_invoice/test_sales_invoice.py
+++ b/erpnext/accounts/doctype/sales_invoice/test_sales_invoice.py
@@ -565,16 +565,17 @@ class TestSalesInvoice(unittest.TestCase):
where against_invoice=%s""", si.doc.name))
def test_recurring_invoice(self):
- from webnotes.utils import now_datetime, get_first_day, get_last_day, add_to_date
- today = now_datetime().date()
-
+ from webnotes.utils import get_first_day, get_last_day, add_to_date, nowdate, getdate
+ from accounts.utils import get_fiscal_year
+ today = nowdate()
base_si = webnotes.bean(copy=test_records[0])
base_si.doc.fields.update({
"convert_into_recurring_invoice": 1,
"recurring_type": "Monthly",
"notification_email_address": "test@example.com, test1@example.com, test2@example.com",
- "repeat_on_day_of_month": today.day,
+ "repeat_on_day_of_month": getdate(today).day,
"posting_date": today,
+ "fiscal_year": get_fiscal_year(today)[0],
"invoice_period_from_date": get_first_day(today),
"invoice_period_to_date": get_last_day(today)
})
diff --git a/erpnext/accounts/report/accounts_payable/accounts_payable.py b/erpnext/accounts/report/accounts_payable/accounts_payable.py
index adb126b0dd..07cca7385e 100644
--- a/erpnext/accounts/report/accounts_payable/accounts_payable.py
+++ b/erpnext/accounts/report/accounts_payable/accounts_payable.py
@@ -9,18 +9,20 @@ from erpnext.accounts.report.accounts_receivable.accounts_receivable import get_
def execute(filters=None):
if not filters: filters = {}
- columns = get_columns()
+ supplier_naming_by = webnotes.conn.get_value("Buying Settings", None, "supp_master_name")
+ columns = get_columns(supplier_naming_by)
entries = get_gl_entries(filters)
- account_supplier = dict(webnotes.conn.sql("""select account.name, supplier.supplier_name
- from `tabAccount` account, `tabSupplier` supplier
- where account.master_type="Supplier" and supplier.name=account.master_name"""))
-
+ account_map = dict(((r.name, r) for r in webnotes.conn.sql("""select acc.name,
+ supp.supplier_name, supp.name as supplier
+ from `tabAccount` acc, `tabSupplier` supp
+ where acc.master_type="Supplier" and supp.name=acc.master_name""", as_dict=1)))
+
entries_after_report_date = [[gle.voucher_type, gle.voucher_no]
for gle in get_gl_entries(filters, before_report_date=False)]
-
+
account_supplier_type_map = get_account_supplier_type_map()
voucher_detail_map = get_voucher_details()
-
+
# Age of the invoice on this date
age_on = getdate(filters.get("report_date")) > getdate(nowdate()) \
and nowdate() or filters.get("report_date")
@@ -37,9 +39,7 @@ def execute(filters=None):
if abs(flt(outstanding_amount)) > 0.01:
paid_amount = invoiced_amount - outstanding_amount
- row = [gle.posting_date, gle.account, account_supplier.get(gle.account, ""),
- gle.voucher_type, gle.voucher_no, gle.remarks,
- account_supplier_type_map.get(gle.account),
+ row = [gle.posting_date, gle.account, gle.voucher_type, gle.voucher_no,
voucher_details.get("due_date", ""), voucher_details.get("bill_no", ""),
voucher_details.get("bill_date", ""), invoiced_amount,
paid_amount, outstanding_amount]
@@ -50,21 +50,38 @@ def execute(filters=None):
else:
ageing_based_on_date = gle.posting_date
- row += get_ageing_data(age_on, ageing_based_on_date, outstanding_amount)
+ row += get_ageing_data(age_on, ageing_based_on_date, outstanding_amount) + \
+ [account_map.get(gle.account).get("supplier") or ""]
+
+ if supplier_naming_by == "Naming Series":
+ row += [account_map.get(gle.account).get("supplier_name") or ""]
+
+ row += [account_supplier_type_map.get(gle.account), gle.remarks]
data.append(row)
-
+
+ for i in range(0, len(data)):
+ data[i].insert(4, """""" \
+ % ("/".join(["#Form", data[i][2], data[i][3]]),))
+
return columns, data
-def get_columns():
- return [
- "Posting Date:Date:80", "Account:Link/Account:150", "Supplier::150", "Voucher Type::110",
- "Voucher No::120", "Remarks::150", "Supplier Type:Link/Supplier Type:120",
- "Due Date:Date:80", "Bill No::80", "Bill Date:Date:80",
+def get_columns(supplier_naming_by):
+ columns = [
+ "Posting Date:Date:80", "Account:Link/Account:150", "Voucher Type::110",
+ "Voucher No::120", "::30", "Due Date:Date:80", "Bill No::80", "Bill Date:Date:80",
"Invoiced Amount:Currency:100", "Paid Amount:Currency:100",
"Outstanding Amount:Currency:100", "Age:Int:50", "0-30:Currency:100",
- "30-60:Currency:100", "60-90:Currency:100", "90-Above:Currency:100"
+ "30-60:Currency:100", "60-90:Currency:100", "90-Above:Currency:100",
+ "Supplier:Link/Supplier:150"
]
-
+
+ if supplier_naming_by == "Naming Series":
+ columns += ["Supplier Name::110"]
+
+ columns += ["Supplier Type:Link/Supplier Type:120", "Remarks::150"]
+
+ return columns
+
def get_gl_entries(filters, before_report_date=True):
conditions, supplier_accounts = get_conditions(filters, before_report_date)
gl_entries = []
@@ -101,10 +118,10 @@ def get_conditions(filters, before_report_date=True):
def get_account_supplier_type_map():
account_supplier_type_map = {}
- for each in webnotes.conn.sql("""select t2.name, t1.supplier_type from `tabSupplier` t1,
- `tabAccount` t2 where t1.name = t2.master_name group by t2.name"""):
+ for each in webnotes.conn.sql("""select acc.name, supp.supplier_type from `tabSupplier` supp,
+ `tabAccount` acc where supp.name = acc.master_name group by acc.name"""):
account_supplier_type_map[each[0]] = each[1]
-
+
return account_supplier_type_map
def get_voucher_details():
diff --git a/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.js b/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.js
index b93f182f31..7f32e261c7 100644
--- a/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.js
+++ b/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.js
@@ -8,6 +8,7 @@ wn.query_reports["Bank Reconciliation Statement"] = {
"label": wn._("Bank Account"),
"fieldtype": "Link",
"options": "Account",
+ "reqd": 1,
"get_query": function() {
return {
"query": "accounts.utils.get_account_list",
@@ -22,7 +23,8 @@ wn.query_reports["Bank Reconciliation Statement"] = {
"fieldname":"report_date",
"label": wn._("Date"),
"fieldtype": "Date",
- "default": get_today()
+ "default": get_today(),
+ "reqd": 1
},
]
}
\ No newline at end of file
diff --git a/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.py b/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.py
index f2a1edda52..646906f907 100644
--- a/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.py
+++ b/erpnext/accounts/report/bank_reconciliation_statement/bank_reconciliation_statement.py
@@ -3,13 +3,14 @@
from __future__ import unicode_literals
import webnotes
-from webnotes import _, msgprint
from webnotes.utils import flt
def execute(filters=None):
if not filters: filters = {}
-
- columns = get_columns()
+
+ debit_or_credit = webnotes.conn.get_value("Account", filters["account"], "debit_or_credit")
+
+ columns = get_columns()
data = get_entries(filters)
from erpnext.accounts.utils import get_balance_on
@@ -20,47 +21,39 @@ def execute(filters=None):
total_debit += flt(d[4])
total_credit += flt(d[5])
- if webnotes.conn.get_value("Account", filters["account"], "debit_or_credit") == 'Debit':
+ if debit_or_credit == 'Debit':
bank_bal = flt(balance_as_per_company) - flt(total_debit) + flt(total_credit)
else:
bank_bal = flt(balance_as_per_company) + flt(total_debit) - flt(total_credit)
data += [
- ["", "", "", "Balance as per company books", balance_as_per_company, ""],
+ get_balance_row("Balance as per company books", balance_as_per_company, debit_or_credit),
["", "", "", "Amounts not reflected in bank", total_debit, total_credit],
- ["", "", "", "Balance as per bank", bank_bal, ""]
+ get_balance_row("Balance as per bank", bank_bal, debit_or_credit)
]
-
- return columns, data
+ return columns, data
def get_columns():
return ["Journal Voucher:Link/Journal Voucher:140", "Posting Date:Date:100",
"Clearance Date:Date:110", "Against Account:Link/Account:200",
"Debit:Currency:120", "Credit:Currency:120"
]
-
-def get_conditions(filters):
- conditions = ""
- if not filters.get("account"):
- msgprint(_("Please select Bank Account"), raise_exception=1)
- else:
- conditions += " and jvd.account = %(account)s"
-
- if not filters.get("report_date"):
- msgprint(_("Please select Date on which you want to run the report"), raise_exception=1)
- else:
- conditions += """ and jv.posting_date <= %(report_date)s
- and ifnull(jv.clearance_date, '4000-01-01') > %(report_date)s"""
-
- return conditions
def get_entries(filters):
- conditions = get_conditions(filters)
- entries = webnotes.conn.sql("""select jv.name, jv.posting_date, jv.clearance_date,
- jvd.against_account, jvd.debit, jvd.credit
- from `tabJournal Voucher Detail` jvd, `tabJournal Voucher` jv
- where jvd.parent = jv.name and jv.docstatus=1 and ifnull(jv.cheque_no, '')!= '' %s
- order by jv.name DESC""" % conditions, filters, as_list=1)
+ entries = webnotes.conn.sql("""select
+ jv.name, jv.posting_date, jv.clearance_date, jvd.against_account, jvd.debit, jvd.credit
+ from
+ `tabJournal Voucher Detail` jvd, `tabJournal Voucher` jv
+ where jvd.parent = jv.name and jv.docstatus=1 and ifnull(jv.cheque_no, '')!= ''
+ and jvd.account = %(account)s and jv.posting_date <= %(report_date)s
+ and ifnull(jv.clearance_date, '4000-01-01') > %(report_date)s
+ order by jv.name DESC""", filters, as_list=1)
- return entries
\ No newline at end of file
+ return entries
+
+def get_balance_row(label, amount, debit_or_credit):
+ if debit_or_credit == "Debit":
+ return ["", "", "", label, amount, 0]
+ else:
+ return ["", "", "", label, 0, amount]
diff --git a/erpnext/accounts/report/general_ledger/general_ledger.py b/erpnext/accounts/report/general_ledger/general_ledger.py
index acfe6a0d86..a22a114a7e 100644
--- a/erpnext/accounts/report/general_ledger/general_ledger.py
+++ b/erpnext/accounts/report/general_ledger/general_ledger.py
@@ -72,6 +72,11 @@ def get_conditions(filters):
if filters.get("voucher_no"):
conditions.append("voucher_no=%(voucher_no)s")
+
+
+ from webnotes.widgets.reportview import build_match_conditions
+ match_conditions = build_match_conditions("GL Entry")
+ if match_conditions: conditions.append(match_conditions)
return "and {}".format(" and ".join(conditions)) if conditions else ""
@@ -136,7 +141,7 @@ def get_accountwise_gle(filters, gl_entries, gle_map):
or cstr(gle.is_advance) == "Yes"):
gle_map[gle.account].opening += amount
opening += amount
- elif gle.posting_date < filters.to_date:
+ elif gle.posting_date <= filters.to_date:
gle_map[gle.account].entries.append(gle)
gle_map[gle.account].total_debit += flt(gle.debit)
gle_map[gle.account].total_credit += flt(gle.credit)
diff --git a/erpnext/accounts/report/item_wise_purchase_register/item_wise_purchase_register.py b/erpnext/accounts/report/item_wise_purchase_register/item_wise_purchase_register.py
index 7d81308a80..7d8a358aa1 100644
--- a/erpnext/accounts/report/item_wise_purchase_register/item_wise_purchase_register.py
+++ b/erpnext/accounts/report/item_wise_purchase_register/item_wise_purchase_register.py
@@ -12,7 +12,8 @@ def execute(filters=None):
item_list = get_items(filters)
aii_account_map = get_aii_accounts()
- item_tax, tax_accounts = get_tax_accounts(item_list, columns)
+ if item_list:
+ item_tax, tax_accounts = get_tax_accounts(item_list, columns)
data = []
for d in item_list:
diff --git a/erpnext/accounts/report/item_wise_sales_register/item_wise_sales_register.py b/erpnext/accounts/report/item_wise_sales_register/item_wise_sales_register.py
index dc5ecda3da..9f1fd87f70 100644
--- a/erpnext/accounts/report/item_wise_sales_register/item_wise_sales_register.py
+++ b/erpnext/accounts/report/item_wise_sales_register/item_wise_sales_register.py
@@ -11,7 +11,8 @@ def execute(filters=None):
last_col = len(columns)
item_list = get_items(filters)
- item_tax, tax_accounts = get_tax_accounts(item_list, columns)
+ if item_list:
+ item_tax, tax_accounts = get_tax_accounts(item_list, columns)
data = []
for d in item_list:
@@ -39,7 +40,6 @@ def get_columns():
"Qty:Float:120", "Rate:Currency:120", "Amount:Currency:120"
]
-
def get_conditions(filters):
conditions = ""
diff --git a/erpnext/accounts/utils.py b/erpnext/accounts/utils.py
index 6d74abd591..5d9c09bcce 100644
--- a/erpnext/accounts/utils.py
+++ b/erpnext/accounts/utils.py
@@ -4,7 +4,7 @@
from __future__ import unicode_literals
import webnotes
-from webnotes.utils import nowdate, nowtime, cstr, flt, now, getdate, add_months
+from webnotes.utils import nowdate, cstr, flt, now, getdate, add_months
from webnotes.model.doc import addchild
from webnotes import msgprint, _
from webnotes.utils import formatdate
@@ -31,6 +31,8 @@ def get_fiscal_years(date=None, fiscal_year=None, label="Date", verbose=1):
if not fy:
error_msg = """%s %s not in any Fiscal Year""" % (label, formatdate(date))
+ error_msg = """{msg}: {date}""".format(msg=_("Fiscal Year does not exist for date"),
+ date=formatdate(date))
if verbose: webnotes.msgprint(error_msg)
raise FiscalYearError, error_msg
@@ -62,7 +64,6 @@ def get_balance_on(account=None, date=None):
try:
year_start_date = get_fiscal_year(date, verbose=0)[1]
except FiscalYearError, e:
- from webnotes.utils import getdate
if getdate(date) > getdate(nowdate()):
# if fiscal year not found and the date is greater than today
# get fiscal year for today's date and its corresponding year start date
@@ -220,17 +221,26 @@ def get_cost_center_list(doctype, txt, searchfield, start, page_len, filters):
tuple(filter_values + ["%%%s%%" % txt, start, page_len]))
def remove_against_link_from_jv(ref_type, ref_no, against_field):
- webnotes.conn.sql("""update `tabJournal Voucher Detail` set `%s`=null,
- modified=%s, modified_by=%s
- where `%s`=%s and docstatus < 2""" % (against_field, "%s", "%s", against_field, "%s"),
- (now(), webnotes.session.user, ref_no))
+ linked_jv = webnotes.conn.sql_list("""select parent from `tabJournal Voucher Detail`
+ where `%s`=%s and docstatus < 2""" % (against_field, "%s"), (ref_no))
+
+ if linked_jv:
+ webnotes.conn.sql("""update `tabJournal Voucher Detail` set `%s`=null,
+ modified=%s, modified_by=%s
+ where `%s`=%s and docstatus < 2""" % (against_field, "%s", "%s", against_field, "%s"),
+ (now(), webnotes.session.user, ref_no))
- webnotes.conn.sql("""update `tabGL Entry`
- set against_voucher_type=null, against_voucher=null,
- modified=%s, modified_by=%s
- where against_voucher_type=%s and against_voucher=%s
- and voucher_no != ifnull(against_voucher, '')""",
- (now(), webnotes.session.user, ref_type, ref_no))
+ webnotes.conn.sql("""update `tabGL Entry`
+ set against_voucher_type=null, against_voucher=null,
+ modified=%s, modified_by=%s
+ where against_voucher_type=%s and against_voucher=%s
+ and voucher_no != ifnull(against_voucher, '')""",
+ (now(), webnotes.session.user, ref_type, ref_no))
+
+ webnotes.msgprint("{msg} {linked_jv}".format(msg = _("""Following linked Journal Vouchers \
+ made against this transaction has been unlinked. You can link them again with other \
+ transactions via Payment Reconciliation Tool."""), linked_jv="\n".join(linked_jv)))
+
@webnotes.whitelist()
def get_company_default(company, fieldname):
diff --git a/erpnext/buying/doctype/purchase_common/purchase_common.js b/erpnext/buying/doctype/purchase_common/purchase_common.js
index cc24925905..ea7a963e4b 100644
--- a/erpnext/buying/doctype/purchase_common/purchase_common.js
+++ b/erpnext/buying/doctype/purchase_common/purchase_common.js
@@ -22,7 +22,7 @@ erpnext.buying.BuyingController = erpnext.TransactionController.extend({
if(this.frm.fields_dict.buying_price_list) {
this.frm.set_query("buying_price_list", function() {
return{
- filters: { 'buying_or_selling': "Buying" }
+ filters: { 'buying': 1 }
}
});
}
@@ -302,11 +302,11 @@ erpnext.buying.BuyingController = erpnext.TransactionController.extend({
calculate_totals: function() {
var tax_count = this.frm.tax_doclist.length;
- this.frm.doc.grand_total = flt(
- tax_count ? this.frm.tax_doclist[tax_count - 1].total : this.frm.doc.net_total,
+ this.frm.doc.grand_total = flt(tax_count ?
+ this.frm.tax_doclist[tax_count - 1].total : this.frm.doc.net_total,
precision("grand_total"));
- this.frm.doc.grand_total_import = flt(this.frm.doc.grand_total / this.frm.doc.conversion_rate,
- precision("grand_total_import"));
+ this.frm.doc.grand_total_import = flt(this.frm.doc.grand_total /
+ this.frm.doc.conversion_rate, precision("grand_total_import"));
this.frm.doc.total_tax = flt(this.frm.doc.grand_total - this.frm.doc.net_total,
precision("total_tax"));
@@ -321,20 +321,26 @@ erpnext.buying.BuyingController = erpnext.TransactionController.extend({
}
// other charges added/deducted
+ this.frm.doc.other_charges_added = 0.0
+ this.frm.doc.other_charges_deducted = 0.0
if(tax_count) {
this.frm.doc.other_charges_added = wn.utils.sum($.map(this.frm.tax_doclist,
- function(tax) { return (tax.add_deduct_tax == "Add" && in_list(["Valuation and Total", "Total"], tax.category)) ? tax.tax_amount : 0.0; }));
+ function(tax) { return (tax.add_deduct_tax == "Add"
+ && in_list(["Valuation and Total", "Total"], tax.category)) ?
+ tax.tax_amount : 0.0; }));
this.frm.doc.other_charges_deducted = wn.utils.sum($.map(this.frm.tax_doclist,
- function(tax) { return (tax.add_deduct_tax == "Deduct" && in_list(["Valuation and Total", "Total"], tax.category)) ? tax.tax_amount : 0.0; }));
+ function(tax) { return (tax.add_deduct_tax == "Deduct"
+ && in_list(["Valuation and Total", "Total"], tax.category)) ?
+ tax.tax_amount : 0.0; }));
- wn.model.round_floats_in(this.frm.doc, ["other_charges_added", "other_charges_deducted"]);
-
- this.frm.doc.other_charges_added_import = flt(this.frm.doc.other_charges_added / this.frm.doc.conversion_rate,
- precision("other_charges_added_import"));
- this.frm.doc.other_charges_deducted_import = flt(this.frm.doc.other_charges_deducted / this.frm.doc.conversion_rate,
- precision("other_charges_deducted_import"));
+ wn.model.round_floats_in(this.frm.doc,
+ ["other_charges_added", "other_charges_deducted"]);
}
+ this.frm.doc.other_charges_added_import = flt(this.frm.doc.other_charges_added /
+ this.frm.doc.conversion_rate, precision("other_charges_added_import"));
+ this.frm.doc.other_charges_deducted_import = flt(this.frm.doc.other_charges_deducted /
+ this.frm.doc.conversion_rate, precision("other_charges_deducted_import"));
},
_cleanup: function() {
diff --git a/erpnext/buying/doctype/purchase_order/test_purchase_order.py b/erpnext/buying/doctype/purchase_order/test_purchase_order.py
index 3659f6ddee..f2c33fc841 100644
--- a/erpnext/buying/doctype/purchase_order/test_purchase_order.py
+++ b/erpnext/buying/doctype/purchase_order/test_purchase_order.py
@@ -22,7 +22,7 @@ class TestPurchaseOrder(unittest.TestCase):
pr = make_purchase_receipt(po.doc.name)
pr[0]["supplier_warehouse"] = "_Test Warehouse 1 - _TC"
-
+ pr[0]["posting_date"] = "2013-05-12"
self.assertEquals(pr[0]["doctype"], "Purchase Receipt")
self.assertEquals(len(pr), len(test_records[0]))
@@ -52,7 +52,7 @@ class TestPurchaseOrder(unittest.TestCase):
self.assertEquals(pr[0]["doctype"], "Purchase Receipt")
self.assertEquals(len(pr), len(test_records[0]))
-
+ pr[0]["posting_date"] = "2013-05-12"
pr[0].naming_series = "_T-Purchase Receipt-"
pr[1].qty = 4.0
pr_bean = webnotes.bean(pr)
@@ -66,6 +66,7 @@ class TestPurchaseOrder(unittest.TestCase):
pr1 = make_purchase_receipt(po.doc.name)
pr1[0].naming_series = "_T-Purchase Receipt-"
+ pr1[0]["posting_date"] = "2013-05-12"
pr1[1].qty = 8
pr1_bean = webnotes.bean(pr1)
pr1_bean.insert()
@@ -88,7 +89,7 @@ class TestPurchaseOrder(unittest.TestCase):
self.assertEquals(pi[0]["doctype"], "Purchase Invoice")
self.assertEquals(len(pi), len(test_records[0]))
-
+ pi[0]["posting_date"] = "2013-05-12"
pi[0].bill_no = "NA"
webnotes.bean(pi).insert()
diff --git a/erpnext/buying/doctype/supplier/supplier.js b/erpnext/buying/doctype/supplier/supplier.js
index e1780abee9..b3dec80cfa 100644
--- a/erpnext/buying/doctype/supplier/supplier.js
+++ b/erpnext/buying/doctype/supplier/supplier.js
@@ -95,6 +95,6 @@ cur_frm.cscript.make_contact = function() {
cur_frm.fields_dict['default_price_list'].get_query = function(doc,cdt,cdn) {
return{
- filters:{'buying_or_selling': "Buying"}
+ filters:{'buying': 1}
}
}
\ No newline at end of file
diff --git a/erpnext/buying/utils.py b/erpnext/buying/utils.py
index 8a4ae3f304..d7e3d81776 100644
--- a/erpnext/buying/utils.py
+++ b/erpnext/buying/utils.py
@@ -3,7 +3,7 @@
from __future__ import unicode_literals
import webnotes
-from webnotes import msgprint, _
+from webnotes import msgprint, _, throw
from webnotes.utils import getdate, flt, add_days, cstr
import json
@@ -90,7 +90,7 @@ def _get_price_list_rate(args, item_bean, meta):
# try fetching from price list
if args.buying_price_list and args.price_list_currency:
price_list_rate = webnotes.conn.sql("""select ref_rate from `tabItem Price`
- where price_list=%s and item_code=%s and buying_or_selling='Buying'""",
+ where price_list=%s and item_code=%s and buying=1""",
(args.buying_price_list, args.item_code), as_dict=1)
if price_list_rate:
@@ -122,14 +122,12 @@ def _validate_item_details(args, item):
# validate if purchase item or subcontracted item
if item.is_purchase_item != "Yes":
- msgprint(_("Item") + (" %s: " % item.name) + _("not a purchase item"),
- raise_exception=True)
+ throw(_("Item") + (" %s: " % item.name) + _("not a purchase item"))
if args.is_subcontracted == "Yes" and item.is_sub_contracted_item != "Yes":
- msgprint(_("Item") + (" %s: " % item.name) +
+ throw(_("Item") + (" %s: " % item.name) +
_("not a sub-contracted item.") +
- _("Please select a sub-contracted item or do not sub-contract the transaction."),
- raise_exception=True)
+ _("Please select a sub-contracted item or do not sub-contract the transaction."))
def get_last_purchase_details(item_code, doc_name=None, conversion_rate=1.0):
"""returns last purchase details in stock uom"""
diff --git a/erpnext/controllers/accounts_controller.py b/erpnext/controllers/accounts_controller.py
index d48a7a6d17..4b7e79b75d 100644
--- a/erpnext/controllers/accounts_controller.py
+++ b/erpnext/controllers/accounts_controller.py
@@ -3,7 +3,7 @@
from __future__ import unicode_literals
import webnotes
-from webnotes import _, msgprint
+from webnotes import _, throw
from webnotes.utils import flt, cint, today, cstr
from webnotes.model.code import get_obj
from erpnext.setup.utils import get_company_currency
@@ -44,14 +44,13 @@ class AccountsController(TransactionBase):
def validate_for_freezed_account(self):
for fieldname in ["customer", "supplier"]:
if self.meta.get_field(fieldname) and self.doc.fields.get(fieldname):
- accounts = webnotes.conn.get_values("Account", {"master_type": fieldname.title(),
- "master_name": self.doc.fields[fieldname], "company": self.doc.company},
- "freeze_account", as_dict=1)
-
+ accounts = webnotes.conn.get_values("Account",
+ {"master_type": fieldname.title(), "master_name": self.doc.fields[fieldname],
+ "company": self.doc.company}, "name")
if accounts:
- if not filter(lambda x: cstr(x.freeze_account) in ["", "No"], accounts):
- msgprint(_("Account for this ") + fieldname + _(" has been freezed. ") +
- self.doc.doctype + _(" can not be made."), raise_exception=1)
+ from accounts.doctype.gl_entry.gl_entry import validate_frozen_account
+ for account in accounts:
+ validate_frozen_account(account[0])
def set_price_list_currency(self, buying_or_selling):
if self.meta.get_field("currency"):
@@ -179,17 +178,17 @@ class AccountsController(TransactionBase):
"""
if tax.charge_type in ["On Previous Row Amount", "On Previous Row Total"] and \
(not tax.row_id or cint(tax.row_id) >= tax.idx):
- msgprint((_("Row") + " # %(idx)s [%(taxes_doctype)s]: " + \
+ throw((_("Row") + " # %(idx)s [%(taxes_doctype)s]: " + \
_("Please specify a valid") + " %(row_id_label)s") % {
"idx": tax.idx,
"taxes_doctype": tax.doctype,
"row_id_label": self.meta.get_label("row_id",
parentfield=self.other_fname)
- }, raise_exception=True)
+ })
def validate_inclusive_tax(self, tax):
def _on_previous_row_error(row_range):
- msgprint((_("Row") + " # %(idx)s [%(doctype)s]: " +
+ throw((_("Row") + " # %(idx)s [%(doctype)s]: " +
_("to be included in Item's rate, it is required that: ") +
" [" + _("Row") + " # %(row_range)s] " + _("also be included in Item's rate")) % {
"idx": tax.idx,
@@ -200,12 +199,12 @@ class AccountsController(TransactionBase):
parentfield=self.other_fname),
"charge_type": tax.charge_type,
"row_range": row_range
- }, raise_exception=True)
+ })
if cint(tax.included_in_print_rate):
if tax.charge_type == "Actual":
# inclusive tax cannot be of type Actual
- msgprint((_("Row")
+ throw((_("Row")
+ " # %(idx)s [%(doctype)s]: %(charge_type_label)s = \"%(charge_type)s\" "
+ "cannot be included in Item's rate") % {
"idx": tax.idx,
@@ -213,7 +212,7 @@ class AccountsController(TransactionBase):
"charge_type_label": self.meta.get_label("charge_type",
parentfield=self.other_fname),
"charge_type": tax.charge_type,
- }, raise_exception=True)
+ })
elif tax.charge_type == "On Previous Row Amount" and \
not cint(self.tax_doclist[tax.row_id - 1].included_in_print_rate):
# referred row should also be inclusive
@@ -224,23 +223,22 @@ class AccountsController(TransactionBase):
_on_previous_row_error("1 - %d" % (tax.row_id,))
def calculate_taxes(self):
- for item in self.item_doclist:
+ # maintain actual tax rate based on idx
+ actual_tax_dict = dict([[tax.idx, tax.rate] for tax in self.tax_doclist
+ if tax.charge_type == "Actual"])
+
+ for n, item in enumerate(self.item_doclist):
item_tax_map = self._load_item_tax_rate(item.item_tax_rate)
for i, tax in enumerate(self.tax_doclist):
# tax_amount represents the amount of tax for the current step
current_tax_amount = self.get_current_tax_amount(item, tax, item_tax_map)
-
- if hasattr(self, "set_item_tax_amount"):
- self.set_item_tax_amount(item, tax, current_tax_amount)
-
- # case when net total is 0 but there is an actual type charge
- # in this case add the actual amount to tax.tax_amount
- # and tax.grand_total_for_current_item for the first such iteration
- if tax.charge_type=="Actual" and \
- not (current_tax_amount or self.doc.net_total or tax.tax_amount):
- zero_net_total_adjustment = flt(tax.rate, self.precision("tax_amount", tax))
- current_tax_amount += zero_net_total_adjustment
+
+ # Adjust divisional loss to the last item
+ if tax.charge_type == "Actual":
+ actual_tax_dict[tax.idx] -= current_tax_amount
+ if n == len(self.item_doclist) - 1:
+ current_tax_amount += actual_tax_dict[tax.idx]
# store tax_amount for current item as it will be used for
# charge type = 'On Previous Row Amount'
@@ -252,7 +250,8 @@ class AccountsController(TransactionBase):
if tax.category:
# if just for valuation, do not add the tax amount in total
# hence, setting it as 0 for further steps
- current_tax_amount = 0.0 if (tax.category == "Valuation") else current_tax_amount
+ current_tax_amount = 0.0 if (tax.category == "Valuation") \
+ else current_tax_amount
current_tax_amount *= -1.0 if (tax.add_deduct_tax == "Deduct") else 1.0
@@ -271,6 +270,11 @@ class AccountsController(TransactionBase):
# in tax.total, accumulate grand total of each item
tax.total += tax.grand_total_for_current_item
+ # set precision in the last item iteration
+ if n == len(self.item_doclist) - 1:
+ tax.total = flt(tax.total, self.precision("total", tax))
+ tax.tax_amount = flt(tax.tax_amount, self.precision("tax_amount", tax))
+
def get_current_tax_amount(self, item, tax, item_tax_map):
tax_rate = self._get_tax_rate(tax, item_tax_map)
current_tax_amount = 0.0
@@ -384,24 +388,45 @@ class AccountsController(TransactionBase):
})
def validate_multiple_billing(self, ref_dt, item_ref_dn, based_on, parentfield):
+ from controllers.status_updater import get_tolerance_for
+ item_tolerance = {}
+ global_tolerance = None
+
for item in self.doclist.get({"parentfield": "entries"}):
if item.fields.get(item_ref_dn):
- already_billed = webnotes.conn.sql("""select sum(%s) from `tab%s`
- where %s=%s and docstatus=1""" % (based_on, self.tname, item_ref_dn, '%s'),
- item.fields[item_ref_dn])[0][0]
-
- max_allowed_amt = flt(webnotes.conn.get_value(ref_dt + " Item",
+ ref_amt = flt(webnotes.conn.get_value(ref_dt + " Item",
item.fields[item_ref_dn], based_on), self.precision(based_on, item))
+ if not ref_amt:
+ webnotes.msgprint(_("As amount for item") + ": " + item.item_code + _(" in ") +
+ ref_dt + _(" is zero, system will not check for over-billed"))
+ else:
+ already_billed = webnotes.conn.sql("""select sum(%s) from `tab%s`
+ where %s=%s and docstatus=1 and parent != %s""" %
+ (based_on, self.tname, item_ref_dn, '%s', '%s'),
+ (item.fields[item_ref_dn], self.doc.name))[0][0]
- total_billed_amt = flt(flt(already_billed) + flt(item.fields[based_on]),
- self.precision(based_on, item))
+ total_billed_amt = flt(flt(already_billed) + flt(item.fields[based_on]),
+ self.precision(based_on, item))
+
+ tolerance, item_tolerance, global_tolerance = get_tolerance_for(item.item_code,
+ item_tolerance, global_tolerance)
- if max_allowed_amt and total_billed_amt - max_allowed_amt > 0.02:
- webnotes.msgprint(_("Row ")+ cstr(item.idx) + ": " + cstr(item.item_code) +
- _(" will be over-billed against mentioned ") + cstr(ref_dt) +
- _(". Max allowed " + cstr(based_on) + ": " + cstr(max_allowed_amt)),
- raise_exception=1)
-
+ max_allowed_amt = flt(ref_amt * (100 + tolerance) / 100)
+
+ if total_billed_amt - max_allowed_amt > 0.01:
+ reduce_by = total_billed_amt - max_allowed_amt
+
+ webnotes.throw(_("Row #") + cstr(item.idx) + ": " +
+ _(" Max amount allowed for Item ") + cstr(item.item_code) +
+ _(" against ") + ref_dt + " " +
+ cstr(item.fields[ref_dt.lower().replace(" ", "_")]) + _(" is ") +
+ cstr(max_allowed_amt) + ". \n" +
+ _("""If you want to increase your overflow tolerance, please increase \
+ tolerance % in Global Defaults or Item master.
+ Or, you must reduce the amount by """) + cstr(reduce_by) + "\n" +
+ _("""Also, please check if the order item has already been billed \
+ in the Sales Order"""))
+
def get_company_default(self, fieldname):
from erpnext.accounts.utils import get_company_default
return get_company_default(self.doc.company, fieldname)
diff --git a/erpnext/controllers/buying_controller.py b/erpnext/controllers/buying_controller.py
index 40de926ea0..7ba29c20bd 100644
--- a/erpnext/controllers/buying_controller.py
+++ b/erpnext/controllers/buying_controller.py
@@ -122,8 +122,8 @@ class BuyingController(StockController):
self.round_floats_in(self.doc, ["net_total", "net_total_import"])
def calculate_totals(self):
- self.doc.grand_total = flt(self.tax_doclist and \
- self.tax_doclist[-1].total or self.doc.net_total, self.precision("grand_total"))
+ self.doc.grand_total = flt(self.tax_doclist[-1].total if self.tax_doclist
+ else self.doc.net_total, self.precision("grand_total"))
self.doc.grand_total_import = flt(self.doc.grand_total / self.doc.conversion_rate,
self.precision("grand_total_import"))
@@ -135,6 +135,24 @@ class BuyingController(StockController):
if self.meta.get_field("rounded_total_import"):
self.doc.rounded_total_import = _round(self.doc.grand_total_import)
+
+ if self.meta.get_field("other_charges_added"):
+ self.doc.other_charges_added = flt(sum([flt(d.tax_amount) for d in self.tax_doclist
+ if d.add_deduct_tax=="Add" and d.category in ["Valuation and Total", "Total"]]),
+ self.precision("other_charges_added"))
+
+ if self.meta.get_field("other_charges_deducted"):
+ self.doc.other_charges_deducted = flt(sum([flt(d.tax_amount) for d in self.tax_doclist
+ if d.add_deduct_tax=="Deduct" and d.category in ["Valuation and Total", "Total"]]),
+ self.precision("other_charges_deducted"))
+
+ if self.meta.get_field("other_charges_added_import"):
+ self.doc.other_charges_added_import = flt(self.doc.other_charges_added /
+ self.doc.conversion_rate, self.precision("other_charges_added_import"))
+
+ if self.meta.get_field("other_charges_deducted_import"):
+ self.doc.other_charges_deducted_import = flt(self.doc.other_charges_deducted /
+ self.doc.conversion_rate, self.precision("other_charges_deducted_import"))
def calculate_outstanding_amount(self):
if self.doc.doctype == "Purchase Invoice" and self.doc.docstatus < 2:
@@ -161,30 +179,49 @@ class BuyingController(StockController):
if not self.meta.get_field("item_tax_amount", parentfield=self.fname):
for item in self.item_doclist:
del item.fields["item_tax_amount"]
-
- def set_item_tax_amount(self, item, tax, current_tax_amount):
+
+ # update valuation rate
+ def update_valuation_rate(self, parentfield):
"""
item_tax_amount is the total tax amount applied on that item
stored for valuation
TODO: rename item_tax_amount to valuation_tax_amount
"""
- if tax.category in ["Valuation", "Valuation and Total"] and \
- self.meta.get_field("item_tax_amount", parentfield=self.fname):
- item.item_tax_amount += flt(current_tax_amount, self.precision("item_tax_amount", item))
-
- # update valuation rate
- def update_valuation_rate(self, parentfield):
- for item in self.doclist.get({"parentfield": parentfield}):
- item.conversion_factor = item.conversion_factor or flt(webnotes.conn.get_value(
- "UOM Conversion Detail", {"parent": item.item_code, "uom": item.uom},
- "conversion_factor")) or 1
+ stock_items = self.get_stock_items()
+
+ stock_items_qty, stock_items_amount = 0, 0
+ last_stock_item_idx = 1
+ for d in self.doclist.get({"parentfield": parentfield}):
+ if d.item_code and d.item_code in stock_items:
+ stock_items_qty += flt(d.qty)
+ stock_items_amount += flt(d.amount)
+ last_stock_item_idx = d.idx
- if item.item_code and item.qty:
+ total_valuation_amount = sum([flt(d.tax_amount) for d in
+ self.doclist.get({"parentfield": "purchase_tax_details"})
+ if d.category in ["Valuation", "Valuation and Total"]])
+
+
+ valuation_amount_adjustment = total_valuation_amount
+ for i, item in enumerate(self.doclist.get({"parentfield": parentfield})):
+ if item.item_code and item.qty and item.item_code in stock_items:
+ item_proportion = flt(item.amount) / stock_items_amount if stock_items_amount \
+ else flt(item.qty) / stock_items_qty
+
+ if i == (last_stock_item_idx - 1):
+ item.item_tax_amount = flt(valuation_amount_adjustment,
+ self.precision("item_tax_amount", item))
+ else:
+ item.item_tax_amount = flt(item_proportion * total_valuation_amount,
+ self.precision("item_tax_amount", item))
+ valuation_amount_adjustment -= item.item_tax_amount
+
self.round_floats_in(item)
-
- # if no item code, which is sometimes the case in purchase invoice,
- # then it is not possible to track valuation against it
+
+ item.conversion_factor = item.conversion_factor or flt(webnotes.conn.get_value(
+ "UOM Conversion Detail", {"parent": item.item_code, "uom": item.uom},
+ "conversion_factor")) or 1
qty_in_stock_uom = flt(item.qty * item.conversion_factor)
item.valuation_rate = ((item.amount + item.item_tax_amount + item.rm_supp_cost)
/ qty_in_stock_uom)
diff --git a/erpnext/controllers/selling_controller.py b/erpnext/controllers/selling_controller.py
index f950f28181..7447121ee6 100644
--- a/erpnext/controllers/selling_controller.py
+++ b/erpnext/controllers/selling_controller.py
@@ -191,7 +191,8 @@ class SellingController(StockController):
self.doc.other_charges_total = flt(self.doc.grand_total - self.doc.net_total,
self.precision("other_charges_total"))
- self.doc.other_charges_total_export = flt(self.doc.grand_total_export - self.doc.net_total_export,
+ self.doc.other_charges_total_export = flt(
+ self.doc.grand_total_export - self.doc.net_total_export,
self.precision("other_charges_total_export"))
self.doc.rounded_total = _round(self.doc.grand_total)
diff --git a/erpnext/controllers/status_updater.py b/erpnext/controllers/status_updater.py
index b2745268f7..1743887bf7 100644
--- a/erpnext/controllers/status_updater.py
+++ b/erpnext/controllers/status_updater.py
@@ -151,7 +151,9 @@ class StatusUpdater(DocListController):
"""
# check if overflow is within tolerance
- tolerance = self.get_tolerance_for(item['item_code'])
+ tolerance, self.tolerance, self.global_tolerance = get_tolerance_for(item['item_code'],
+ self.tolerance, self.global_tolerance)
+
overflow_percent = ((item[args['target_field']] - item[args['target_ref_field']]) /
item[args['target_ref_field']]) * 100
@@ -170,23 +172,6 @@ class StatusUpdater(DocListController):
Also, please check if the order item has already been billed in the Sales Order""" %
item, raise_exception=1)
-
- def get_tolerance_for(self, item_code):
- """
- Returns the tolerance for the item, if not set, returns global tolerance
- """
- if self.tolerance.get(item_code): return self.tolerance[item_code]
-
- tolerance = flt(webnotes.conn.get_value('Item',item_code,'tolerance') or 0)
-
- if not tolerance:
- if self.global_tolerance == None:
- self.global_tolerance = flt(webnotes.conn.get_value('Global Defaults', None,
- 'tolerance'))
- tolerance = self.global_tolerance
-
- self.tolerance[item_code] = tolerance
- return tolerance
def update_qty(self, change_modified=True):
@@ -245,4 +230,59 @@ class StatusUpdater(DocListController):
set %(status_field)s = if(ifnull(%(target_parent_field)s,0)<0.001,
'Not %(keyword)s', if(%(target_parent_field)s>=99.99,
'Fully %(keyword)s', 'Partly %(keyword)s'))
- where name='%(name)s'""" % args)
\ No newline at end of file
+ where name='%(name)s'""" % args)
+
+
+ def update_billing_status_for_zero_amount_refdoc(self, ref_dt):
+ ref_fieldname = ref_dt.lower().replace(" ", "_")
+ zero_amount_refdoc = []
+ all_zero_amount_refdoc = webnotes.conn.sql_list("""select name from `tab%s`
+ where docstatus=1 and net_total = 0""" % ref_dt)
+
+ for item in self.doclist.get({"parentfield": "entries"}):
+ if item.fields.get(ref_fieldname) \
+ and item.fields.get(ref_fieldname) in all_zero_amount_refdoc \
+ and item.fields.get(ref_fieldname) not in zero_amount_refdoc:
+ zero_amount_refdoc.append(item.fields[ref_fieldname])
+
+ if zero_amount_refdoc:
+ self.update_biling_status(zero_amount_refdoc, ref_dt, ref_fieldname)
+
+ def update_biling_status(self, zero_amount_refdoc, ref_dt, ref_fieldname):
+ for ref_dn in zero_amount_refdoc:
+ ref_doc_qty = flt(webnotes.conn.sql("""select sum(ifnull(qty, 0)) from `tab%s Item`
+ where parent=%s""" % (ref_dt, '%s'), (ref_dn))[0][0])
+
+ billed_qty = flt(webnotes.conn.sql("""select sum(ifnull(qty, 0))
+ from `tab%s Item` where %s=%s and docstatus=1""" %
+ (self.doc.doctype, ref_fieldname, '%s'), (ref_dn))[0][0])
+
+ per_billed = ((ref_doc_qty if billed_qty > ref_doc_qty else billed_qty)\
+ / ref_doc_qty)*100
+ webnotes.conn.set_value(ref_dt, ref_dn, "per_billed", per_billed)
+
+ from webnotes.model.meta import has_field
+ if has_field(ref_dt, "billing_status"):
+ if per_billed < 0.001: billing_status = "Not Billed"
+ elif per_billed >= 99.99: billing_status = "Fully Billed"
+ else: billing_status = "Partly Billed"
+
+ webnotes.conn.set_value(ref_dt, ref_dn, "billing_status", billing_status)
+
+def get_tolerance_for(item_code, item_tolerance={}, global_tolerance=None):
+ """
+ Returns the tolerance for the item, if not set, returns global tolerance
+ """
+ if item_tolerance.get(item_code):
+ return item_tolerance[item_code], item_tolerance, global_tolerance
+
+ tolerance = flt(webnotes.conn.get_value('Item',item_code,'tolerance') or 0)
+
+ if not tolerance:
+ if global_tolerance == None:
+ global_tolerance = flt(webnotes.conn.get_value('Global Defaults', None,
+ 'tolerance'))
+ tolerance = global_tolerance
+
+ item_tolerance[item_code] = tolerance
+ return tolerance, item_tolerance, global_tolerance
\ No newline at end of file
diff --git a/erpnext/hr/doctype/salary_manager/salary_manager.js b/erpnext/hr/doctype/salary_manager/salary_manager.js
index 032c29e509..ec485ca671 100644
--- a/erpnext/hr/doctype/salary_manager/salary_manager.js
+++ b/erpnext/hr/doctype/salary_manager/salary_manager.js
@@ -43,7 +43,7 @@ cur_frm.cscript.make_jv = function(doc, dt, dn) {
jv = locals['Journal Voucher'][jv];
jv.voucher_type = 'Bank Voucher';
jv.user_remark = wn._('Payment of salary for the month: ') + doc.month +
- wn._('and fiscal year: ') + doc.fiscal_year;
+ wn._(' and fiscal year: ') + doc.fiscal_year;
jv.fiscal_year = doc.fiscal_year;
jv.company = doc.company;
jv.posting_date = dateutil.obj_to_str(new Date());
diff --git a/erpnext/hr/report/monthly_salary_register/monthly_salary_register.js b/erpnext/hr/report/monthly_salary_register/monthly_salary_register.js
index 5d3abccde9..32b4ef35fb 100644
--- a/erpnext/hr/report/monthly_salary_register/monthly_salary_register.js
+++ b/erpnext/hr/report/monthly_salary_register/monthly_salary_register.js
@@ -7,7 +7,7 @@ wn.query_reports["Monthly Salary Register"] = {
"fieldname":"month",
"label": wn._("Month"),
"fieldtype": "Select",
- "options": "Jan\nFeb\nMar\nApr\nMay\nJun\nJul\nAug\nSep\nOct\nNov\nDec",
+ "options": "\nJan\nFeb\nMar\nApr\nMay\nJun\nJul\nAug\nSep\nOct\nNov\nDec",
"default": ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov",
"Dec"][wn.datetime.str_to_obj(wn.datetime.get_today()).getMonth()],
},
diff --git a/erpnext/hr/report/monthly_salary_register/monthly_salary_register.py b/erpnext/hr/report/monthly_salary_register/monthly_salary_register.py
index 8bd8f36ac8..42c62e474b 100644
--- a/erpnext/hr/report/monthly_salary_register/monthly_salary_register.py
+++ b/erpnext/hr/report/monthly_salary_register/monthly_salary_register.py
@@ -50,17 +50,17 @@ def get_columns(salary_slips):
where ifnull(d_modified_amount, 0) != 0 and parent in (%s)""" %
(', '.join(['%s']*len(salary_slips))), tuple([d.name for d in salary_slips]))
- columns = columns + [(e + ":Link/Earning Type:120") for e in earning_types] + \
+ columns = columns + [(e + ":Currency:120") for e in earning_types] + \
["Arrear Amount:Currency:120", "Leave Encashment Amount:Currency:150",
- "Gross Pay:Currency:120"] + [(d + ":Link/Deduction Type:120") for d in ded_types] + \
+ "Gross Pay:Currency:120"] + [(d + ":Currency:120") for d in ded_types] + \
["Total Deduction:Currency:120", "Net Pay:Currency:120"]
return columns, earning_types, ded_types
def get_salary_slips(filters):
conditions, filters = get_conditions(filters)
- salary_slips = webnotes.conn.sql("""select * from `tabSalary Slip` where docstatus = 1 %s""" %
- conditions, filters, as_dict=1)
+ salary_slips = webnotes.conn.sql("""select * from `tabSalary Slip` where docstatus = 1 %s
+ order by employee, month""" % conditions, filters, as_dict=1)
if not salary_slips:
msgprint(_("No salary slip found for month: ") + cstr(filters.get("month")) +
@@ -102,6 +102,6 @@ def get_ss_ded_map(salary_slips):
ss_ded_map = {}
for d in ss_deductions:
ss_ded_map.setdefault(d.parent, webnotes._dict()).setdefault(d.d_type, [])
- ss_ded_map[d.parent][d.e_type] = flt(d.d_modified_amount)
+ ss_ded_map[d.parent][d.d_type] = flt(d.d_modified_amount)
return ss_ded_map
\ No newline at end of file
diff --git a/erpnext/manufacturing/doctype/production_order/test_production_order.py b/erpnext/manufacturing/doctype/production_order/test_production_order.py
index 9b1300f039..e2ff92174e 100644
--- a/erpnext/manufacturing/doctype/production_order/test_production_order.py
+++ b/erpnext/manufacturing/doctype/production_order/test_production_order.py
@@ -35,6 +35,8 @@ class TestProductionOrder(unittest.TestCase):
stock_entry = webnotes.bean(stock_entry)
stock_entry.doc.fiscal_year = "_Test Fiscal Year 2013"
stock_entry.doc.fg_completed_qty = 4
+ stock_entry.doc.posting_date = "2013-05-12"
+ stock_entry.doc.fiscal_year = "_Test Fiscal Year 2013"
stock_entry.run_method("get_items")
stock_entry.submit()
@@ -51,6 +53,7 @@ class TestProductionOrder(unittest.TestCase):
stock_entry = make_stock_entry(pro_order, "Manufacture/Repack")
stock_entry = webnotes.bean(stock_entry)
+ stock_entry.doc.posting_date = "2013-05-12"
stock_entry.doc.fiscal_year = "_Test Fiscal Year 2013"
stock_entry.doc.fg_completed_qty = 15
stock_entry.run_method("get_items")
diff --git a/erpnext/setup/report/__init__.py b/erpnext/patches/1401/__init__.py
similarity index 100%
rename from erpnext/setup/report/__init__.py
rename to erpnext/patches/1401/__init__.py
diff --git a/erpnext/patches/1401/p01_make_buying_selling_as_check_box_in_price_list.py b/erpnext/patches/1401/p01_make_buying_selling_as_check_box_in_price_list.py
new file mode 100644
index 0000000000..b764a7f935
--- /dev/null
+++ b/erpnext/patches/1401/p01_make_buying_selling_as_check_box_in_price_list.py
@@ -0,0 +1,29 @@
+# Copyright (c) 2014, Web Notes Technologies Pvt. Ltd. and Contributors
+# License: GNU General Public License v3. See license.txt
+
+from __future__ import unicode_literals
+import webnotes
+
+def execute():
+ webnotes.reload_doc("stock", "doctype", "price_list")
+ webnotes.reload_doc("stock", "doctype", "item_price")
+
+ if "buying_or_selling" in webnotes.conn.get_table_columns("Price List"):
+ webnotes.conn.sql("""update `tabPrice List` set
+ selling =
+ case
+ when buying_or_selling='Selling'
+ then 1
+ end,
+ buying =
+ case
+ when buying_or_selling='Buying'
+ then 1
+ end
+ """)
+ webnotes.conn.sql("""update `tabItem Price` ip, `tabPrice List` pl
+ set ip.buying=pl.buying, ip.selling=pl.selling
+ where ip.price_list=pl.name""")
+
+ webnotes.conn.sql("""update `tabItem Price` set selling=1 where ifnull(selling, 0)=0 and
+ ifnull(buying, 0)=0""")
\ No newline at end of file
diff --git a/erpnext/patches/1401/p01_move_related_property_setters_to_custom_field.py b/erpnext/patches/1401/p01_move_related_property_setters_to_custom_field.py
new file mode 100644
index 0000000000..cf9221bcfd
--- /dev/null
+++ b/erpnext/patches/1401/p01_move_related_property_setters_to_custom_field.py
@@ -0,0 +1,25 @@
+# Copyright (c) 2013, Web Notes Technologies Pvt. Ltd. and Contributors
+# License: GNU General Public License v3. See license.txt
+
+import webnotes
+
+def execute():
+ webnotes.reload_doc("core", "doctype", "custom_field")
+
+ cf_doclist = webnotes.get_doctype("Custom Field")
+
+ delete_list = []
+ for d in webnotes.conn.sql("""select cf.name as cf_name, ps.property,
+ ps.value, ps.name as ps_name
+ from `tabProperty Setter` ps, `tabCustom Field` cf
+ where ps.doctype_or_field = 'DocField' and ps.property != 'previous_field'
+ and ps.doc_type=cf.dt and ps.field_name=cf.fieldname""", as_dict=1):
+ if cf_doclist.get_field(d.property):
+ webnotes.conn.sql("""update `tabCustom Field`
+ set `%s`=%s where name=%s""" % (d.property, '%s', '%s'), (d.value, d.cf_name))
+
+ delete_list.append(d.ps_name)
+
+ if delete_list:
+ webnotes.conn.sql("""delete from `tabProperty Setter` where name in (%s)""" %
+ ', '.join(['%s']*len(delete_list)), tuple(delete_list))
\ No newline at end of file
diff --git a/erpnext/patches/1401/update_billing_status_for_zero_value_order.py b/erpnext/patches/1401/update_billing_status_for_zero_value_order.py
new file mode 100644
index 0000000000..afeed55ed4
--- /dev/null
+++ b/erpnext/patches/1401/update_billing_status_for_zero_value_order.py
@@ -0,0 +1,29 @@
+# Copyright (c) 2013, Web Notes Technologies Pvt. Ltd. and Contributors
+# License: GNU General Public License v3. See license.txt
+
+import webnotes
+from webnotes.utils import flt
+
+def execute():
+ for order_type in ["Sales", "Purchase"]:
+ for d in webnotes.conn.sql("""select par.name, sum(ifnull(child.qty, 0)) as total_qty
+ from `tab%s Order` par, `tab%s Order Item` child
+ where par.name = child.parent and par.docstatus = 1
+ and ifnull(par.net_total, 0) = 0 group by par.name""" %
+ (order_type, order_type), as_dict=1):
+
+ billed_qty = flt(webnotes.conn.sql("""select sum(ifnull(qty, 0))
+ from `tab%s Invoice Item` where %s=%s and docstatus=1""" %
+ (order_type, "sales_order" if order_type=="Sales" else "purchase_order", '%s'),
+ (d.name))[0][0])
+
+ per_billed = ((d.total_qty if billed_qty > d.total_qty else billed_qty)\
+ / d.total_qty)*100
+ webnotes.conn.set_value(order_type+ " Order", d.name, "per_billed", per_billed)
+
+ if order_type == "Sales":
+ if per_billed < 0.001: billing_status = "Not Billed"
+ elif per_billed >= 99.99: billing_status = "Fully Billed"
+ else: billing_status = "Partly Billed"
+
+ webnotes.conn.set_value("Sales Order", d.name, "billing_status", billing_status)
\ No newline at end of file
diff --git a/erpnext/patches/june_2013/p03_buying_selling_for_price_list.py b/erpnext/patches/june_2013/p03_buying_selling_for_price_list.py
index 2f92fe6a9e..15da085e53 100644
--- a/erpnext/patches/june_2013/p03_buying_selling_for_price_list.py
+++ b/erpnext/patches/june_2013/p03_buying_selling_for_price_list.py
@@ -8,20 +8,7 @@ from webnotes.utils import cint
def execute():
webnotes.reload_doc("stock", "doctype", "price_list")
webnotes.reload_doc("stock", "doctype", "item_price")
-
- try:
- for price_list in webnotes.conn.sql_list("""select name from `tabPrice List`"""):
- buying, selling = False, False
- for b, s in webnotes.conn.sql("""select distinct buying, selling
- from `tabItem Price` where price_list_name=%s""", price_list):
- buying = buying or cint(b)
- selling = selling or cint(s)
-
- buying_or_selling = "Selling" if selling else "Buying"
- webnotes.conn.set_value("Price List", price_list, "buying_or_selling", buying_or_selling)
- except webnotes.SQLError, e:
- if e.args[0] == 1054:
- webnotes.conn.sql("""update `tabPrice List` set buying_or_selling='Selling'
- where ifnull(buying_or_selling, '')='' """)
- else:
- raise
\ No newline at end of file
+
+ webnotes.conn.sql("""update `tabPrice List` pl, `tabItem Price` ip
+ set pl.selling=ip.selling, pl.buying=ip.buying
+ where pl.name=ip.price_list_name""")
\ No newline at end of file
diff --git a/erpnext/patches/october_2013/p02_update_price_list_and_item_details_in_item_price.py b/erpnext/patches/october_2013/p02_update_price_list_and_item_details_in_item_price.py
index 3b4ca833f1..b92f7d052a 100644
--- a/erpnext/patches/october_2013/p02_update_price_list_and_item_details_in_item_price.py
+++ b/erpnext/patches/october_2013/p02_update_price_list_and_item_details_in_item_price.py
@@ -12,9 +12,7 @@ def execute():
where ip.item_code=i.name""")
webnotes.conn.sql("""update `tabItem Price` ip, `tabPrice List` pl
- set ip.price_list=pl.name, ip.currency=pl.currency,
- ip.buying_or_selling=pl.buying_or_selling
- where ip.parent=pl.name""")
+ set ip.price_list=pl.name, ip.currency=pl.currency where ip.parent=pl.name""")
webnotes.conn.sql("""update `tabItem Price`
set parent=null, parenttype=null, parentfield=null, idx=null""")
\ No newline at end of file
diff --git a/erpnext/patches/patch_list.py b/erpnext/patches/patch_list.py
index e455913f59..7c4ac332b0 100644
--- a/erpnext/patches/patch_list.py
+++ b/erpnext/patches/patch_list.py
@@ -262,4 +262,7 @@ patch_list = [
"execute:webnotes.delete_doc('DocType', 'Warehouse Type')",
"patches.1312.p01_delete_old_stock_reports",
"patches.1312.p02_update_item_details_in_item_price",
+ "patches.1401.p01_move_related_property_setters_to_custom_field",
+ "patches.1401.p01_make_buying_selling_as_check_box_in_price_list",
+ "patches.1401.update_billing_status_for_zero_value_order",
]
\ No newline at end of file
diff --git a/erpnext/public/js/conf.js b/erpnext/public/js/conf.js
index d902fe1fdc..73099d1f37 100644
--- a/erpnext/public/js/conf.js
+++ b/erpnext/public/js/conf.js
@@ -24,14 +24,16 @@ $(document).bind('toolbar_setup', function() {
wn.provide('wn.ui.misc');
wn.ui.misc.about = function() {
if(!wn.ui.misc.about_dialog) {
- var d = new wn.ui.Dialog({title: wn._('About ERPNext')})
+ var d = new wn.ui.Dialog({title: wn._('About')})
$(d.body).html(repl("
\
-
"+wn._("ERPNext is an open-source web based ERP made by Web Notes Technologies Pvt Ltd. to provide an integrated tool to manage most processes in a small organization. For more information about Web Notes, or to buy hosting servies, go to ")+
- "https://erpnext.com.
diff --git a/erpnext/accounts/report/accounts_receivable/accounts_receivable.py b/erpnext/accounts/report/accounts_receivable/accounts_receivable.py
index 945bae434a..de96abb7d7 100644
--- a/erpnext/accounts/report/accounts_receivable/accounts_receivable.py
+++ b/erpnext/accounts/report/accounts_receivable/accounts_receivable.py
@@ -15,26 +15,34 @@ class AccountsReceivableReport(object):
else self.filters.report_date
def run(self):
- return self.get_columns(), self.get_data()
+ customer_naming_by = webnotes.conn.get_value("Selling Settings", None, "cust_master_name")
+ return self.get_columns(customer_naming_by), self.get_data(customer_naming_by)
- def get_columns(self):
- return [
+ def get_columns(self, customer_naming_by):
+ columns = [
"Posting Date:Date:80", "Account:Link/Account:150",
"Voucher Type::110", "Voucher No::120", "::30",
"Due Date:Date:80",
"Invoiced Amount:Currency:100", "Payment Received:Currency:100",
"Outstanding Amount:Currency:100", "Age:Int:50", "0-30:Currency:100",
"30-60:Currency:100", "60-90:Currency:100", "90-Above:Currency:100",
- "Customer:Link/Customer:200", "Territory:Link/Territory:80", "Remarks::200"
+ "Customer:Link/Customer:200"
]
-
- def get_data(self):
+
+ if customer_naming_by == "Naming Series":
+ columns += ["Customer Name::110"]
+
+ columns += ["Territory:Link/Territory:80", "Remarks::200"]
+
+ return columns
+
+ def get_data(self, customer_naming_by):
data = []
future_vouchers = self.get_entries_after(self.filters.report_date)
for gle in self.get_entries_till(self.filters.report_date):
if self.is_receivable(gle, future_vouchers):
outstanding_amount = self.get_outstanding_amount(gle, self.filters.report_date)
- if abs(outstanding_amount) > 0.01:
+ if abs(outstanding_amount) > 0.0:
due_date = self.get_due_date(gle)
invoiced_amount = gle.debit if (gle.debit > 0) else 0
payment_received = invoiced_amount - outstanding_amount
@@ -42,18 +50,23 @@ class AccountsReceivableReport(object):
gle.voucher_type, gle.voucher_no, due_date,
invoiced_amount, payment_received,
outstanding_amount]
- entry_date = due_date if self.filters.ageing_based_on=="Due Date" \
+ entry_date = due_date if self.filters.ageing_based_on == "Due Date" \
else gle.posting_date
- row += get_ageing_data(self.age_as_on, entry_date, outstanding_amount)
- row += [self.get_customer(gle.account), self.get_territory(gle.account), gle.remarks]
+ row += get_ageing_data(self.age_as_on, entry_date, outstanding_amount) + \
+ [self.get_customer(gle.account)]
+
+ if customer_naming_by == "Naming Series":
+ row += [self.get_customer_name(gle.account)]
+
+ row += [self.get_territory(gle.account), gle.remarks]
data.append(row)
- for i in range(0,len(data)):
+ for i in range(0, len(data)):
data[i].insert(4, """""" \
% ("/".join(["#Form", data[i][2], data[i][3]]),))
return data
-
+
def get_entries_after(self, report_date):
# returns a distinct list
return list(set([(e.voucher_type, e.voucher_no) for e in self.get_gl_entries()
@@ -65,30 +78,41 @@ class AccountsReceivableReport(object):
if getdate(e.posting_date) <= report_date)
def is_receivable(self, gle, future_vouchers):
- return ((not gle.against_voucher) or (gle.against_voucher==gle.voucher_no) or
- ((gle.against_voucher_type, gle.against_voucher) in future_vouchers))
+ return (
+ # advance
+ (not gle.against_voucher) or
+
+ # sales invoice
+ (gle.against_voucher==gle.voucher_no and gle.debit > 0) or
+
+ # entries adjusted with future vouchers
+ ((gle.against_voucher_type, gle.against_voucher) in future_vouchers)
+ )
def get_outstanding_amount(self, gle, report_date):
payment_received = 0.0
for e in self.get_gl_entries_for(gle.account, gle.voucher_type, gle.voucher_no):
if getdate(e.posting_date) <= report_date and e.name!=gle.name:
payment_received += (flt(e.credit) - flt(e.debit))
-
+
return flt(gle.debit) - flt(gle.credit) - payment_received
def get_customer(self, account):
+ return self.get_account_map().get(account).get("customer") or ""
+
+ def get_customer_name(self, account):
return self.get_account_map().get(account).get("customer_name") or ""
-
+
def get_territory(self, account):
return self.get_account_map().get(account).get("territory") or ""
def get_account_map(self):
if not hasattr(self, "account_map"):
self.account_map = dict(((r.name, r) for r in webnotes.conn.sql("""select
- account.name, customer.name as customer_name, customer.territory
- from `tabAccount` account, `tabCustomer` customer
- where account.master_type="Customer"
- and customer.name=account.master_name""", as_dict=True)))
+ acc.name, cust.name as customer, cust.customer_name, cust.territory
+ from `tabAccount` acc, `tabCustomer` cust
+ where acc.master_type="Customer"
+ and cust.name=acc.master_name""", as_dict=True)))
return self.account_map
@@ -147,7 +171,7 @@ class AccountsReceivableReport(object):
def execute(filters=None):
return AccountsReceivableReport(filters).run()
-
+
def get_ageing_data(age_as_on, entry_date, outstanding_amount):
# [0-30, 30-60, 60-90, 90-above]
outstanding_range = [0.0, 0.0, 0.0, 0.0]